{% load static %}
{% load evelinks %}

{% if TNNT_TEMPLATE_ENTITY_ID == 1 %}
    <img class="rounded-circle my-3" src="{{ TNNT_TEMPLATE_AA_LOGO }}" style="display: inline-block;" width="{{ logo_width|default:"64" }}" height="{% if logo_height %}{{ logo_ }}{% else %}{{ logo_width|default:"64" }}{% endif %}" alt="{{ TNNT_TEMPLATE_ENTITY_NAME|default:SITE_NAME }}">
{% else %}
    {% if TNNT_TEMPLATE_ENTITY_TYPE == 'alliance' %}
        <img class="rounded-circle my-3" src="{{ TNNT_TEMPLATE_ENTITY_ID|alliance_logo_url:256 }}" style="display: inline-block;" width="{{ logo_width|default:"64" }}" height="{% if logo_height %}{{ logo_ }}{% else %}{{ logo_width|default:"64" }}{% endif %}" alt="{{ TNNT_TEMPLATE_ENTITY_NAME|default:SITE_NAME }}">
    {% elif TNNT_TEMPLATE_ENTITY_TYPE == 'corporation' %}
        <img class="rounded-circle my-3" src="{{ TNNT_TEMPLATE_ENTITY_ID|corporation_logo_url:256 }}" style="display: inline-block;" width="{{ logo_width|default:"64" }}" height="{% if logo_height %}{{ logo_ }}{% else %}{{ logo_width|default:"64" }}{% endif %}" alt="{{ TNNT_TEMPLATE_ENTITY_NAME|default:SITE_NAME }}">
    {% endif %}
{% endif %}
