/* Bootstrap defaults overrides
------------------------------------------------------------------------------------- */

@media all {
    .progress-bar {
        color: rgba(var(--bs-light-rgb), var(--bs-text-opacity)) !important; /* stylelint-disable-line color-function-notation */

        --bs-text-opacity: 1;

        text-shadow: -1px -1px 0 rgba(0 0 0 / 30%);
    }

    .table {
        --bs-table-bg: var(--background-color-light-transparency) !important;
    }
}

/* END Bootstrap defaults overrides
------------------------------------------------------------------------------------- */


/* Bootstrap fixes
------------------------------------------------------------------------------------- */

@media all {
    .navbar-brand {
        padding-left: 0;
        margin-right: var(--bs-navbar-brand-margin-end);
    }
}

/* END Bootstrap fixes
------------------------------------------------------------------------------------- */


/* Terra Nanotech theme
------------------------------------------------------------------------------------- */

@media all {
    html {
        font-family: var(--font-family-default);
    }

    body {
        background: var(--background-body-default) !important;
        background-size: cover !important;
        font-family: var(--font-family-default);
    }

    body,
    body > nav.navbar,
    .modal.fade.show {
        backdrop-filter: var(--backdrop-filter-default);
    }

    body,
    #sidebar > div > div,
    body > main > div + div,
    .card {
        background-color: var(--background-color-light-transparency) !important;
    }

    #sidebar > div > div > div > div {
        background-color: transparent !important;
    }

    .nav-pills .nav-link {
        background-image: none;
        border: 1px solid transparent;
    }

    .nav-pills .nav-link.active, .nav-pills .nav-link:hover {
        backdrop-filter: var(--backdrop-filter-default);
        background-color: var(--background-color-light-transparency) !important;
        background-image: none;
        filter: none;
    }

    .h1,
    .h2,
    .h3,
    .h4,
    .h5,
    .h6,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6 {
        font-family: var(--font-family-default);
        font-weight: 400;
    }

    .tooltip {
        font-family: var(--font-family-default);
    }

    .popover {
        font-family: var(--font-family-default);
    }

    code {
        background-color: var(--background-color-light-transparency);
        border-radius: var(--bs-border-radius);
        font-family: var(--font-family-code);
        padding: 0.25rem;
    }

    pre code {
        display: block;
    }

    #aa-dashboard-panel-software-version ul > li > .btn {
        border: none;
        color: inherit;
    }

    td p:last-child {
        margin-bottom: 0;
    }

    .text-decoration-none {
        text-decoration: none !important;
    }

    blockquote {
        font-size: 0.95rem;
    }

    #aa-user-info button[data-bs-toggle="dropdown"] {
        border: none;
    }

    .card-title,
    .modal-title {
        color: var(--white);
        display: block;
        font-family: var(--font-family-card-title);
        font-size: 1rem !important;
        font-weight: 700;
        margin-top: 0.25rem;
        text-shadow: -1px -1px 0 rgba(0 0 0/30%);
    }

    /* Overflowing panel: Right padding on vertical overflow */
    .overflowing.overflowing-vertically {
        padding-right: 0.5rem !important;
    }

    /* Overflowing panel: Right padding on vertical overflow */
    .overflowing.overflowing-horizontally {
        padding-bottom: 0.5rem !important;
    }

    /* Character panel: "Add Character" button */
    #aa-dashboard-panel-characters a.btn[href^="/account/characters/add/"] {
        margin-left: 0 !important;
    }

    /* Character panel: "Change Main" button */
    #aa-dashboard-panel-characters a.btn[href^="/account/characters/main/"] {
        margin-right: 0 !important;
    }

    /* Images: Rounded corners, when not defined otherwise already */
    img:not([class*="rounded"], [class*="rounded-circle"]) {
        border-radius: var(--bs-border-radius) !important;
    }

    /* Login page
    --------------------------------------------------------------------------------- */

    body:has(div.card-login) {
        backdrop-filter: none;
        height: 100vh;
        position: relative;
    }

    body:has(div.card-login) div.container {
        backdrop-filter: var(--backdrop-filter-default);
        left: 0;
        margin: 0 !important;
        max-width: 100% !important;
        padding: 2rem 0;
        position: absolute;
        right: 0;
        top: 50%;
        transform: translateY(-50%);
    }

    body:has(div.card-login) div.container > div.row {
        max-width: 100%;
    }

    /* END Login page
    --------------------------------------------------------------------------------- */
}

/* END Terra Nanotech theme
------------------------------------------------------------------------------------- */
