/* All my apps
------------------------------------------------------------------------------------- */

@media all {
    div:has(> div.app-translation-footer) {
        border-color: rgba(var(--bs-secondary-rgb), var(--bs-border-opacity)) !important; /* stylelint-disable-line color-function-notation */

        --bs-border-opacity: 1;
    }
}

/* END All my apps
------------------------------------------------------------------------------------- */

/* CKEditor 5 style fixes
------------------------------------------------------------------------------------- */

@media all {
    .ck-rounded-corners {
        --ck-border-radius: var(--bs-border-radius);
    }

    .ck-editor__editable {
        color: initial;
    }

    .ck-word-count {
        color: var(--bs-secondary-color) !important;

        --bs-text-opacity: 1;
    }
}

/* END CKEditor 5 style fixes
------------------------------------------------------------------------------------- */

/* App: AA Sovtimer
------------------------------------------------------------------------------------- */

@media all {
    .aa-sovtimer .aa-sovtimer-timer-elapsed {
        color: rgb(253 126 20);
        text-shadow: 1px 1px 1px rgba(255 0 0 / 30%);
    }

    .aa-sovtimer-active-campaign {
        color: var(--bs-table-color);

        --bs-table-active-bg: rgb(240 111 107);
        --bs-table-bg: var(--bs-danger);
        --bs-table-border-color: rgb(241 127 124);
        --bs-table-hover-bg: rgb(239 107 103);
        --bs-table-striped-bg: rgb(239 103 99);
    }

    .aa-sovtimer-active-campaign td {
        background-color: rgba(238 95 91 / 25%) !important;
    }

    .aa-sovtimer-upcoming-campaign {
        color: var(--bs-table-color);

        --bs-table-active-bg: rgb(249 159 31);
        --bs-table-bg: var(--bs-warning);
        --bs-table-border-color: rgb(249 169 56);
        --bs-table-hover-bg: rgb(249 156 25);
        --bs-table-striped-bg: rgb(248 153 18);
    }

    .aa-sovtimer-upcoming-campaign td {
        background-color: rgba(248 148 6 / 25%) !important;
    }
}

/* END App: AA Sovtimer
------------------------------------------------------------------------------------- */

/* App: AA Forum
------------------------------------------------------------------------------------- */
@media all {
    .aa-forum .aa-forum-header {
        margin-bottom: 1rem;
    }

    .aa-forum .aa-forum-admin-panel-aa-forum-category .panel-body {
        min-height: auto;
    }

    .aa-forum .boards-sortable > li {
        background-color: rgba(62 68 76 / 60%);
    }

    .aa-forum .panel-aa-forum-topic-list {
        margin: 1.25rem 0;
    }

    .aa-forum .aa-forum-topic-row .aa-forum-topic:hover,
    .aa-forum .panel-aa-forum-category .aa-forum-board:hover,
    .aa-forum .panel-aa-forum-personal-messages-item:hover {
        background-color: rgba(73 81 90 / 65%);
    }

    .aa-forum .aa-forum-topic-locked .aa-forum-topic:hover {
        background-color: rgba(185 199 219 / 25%);
    }

    .aa-forum .aa-forum-topic-sticky .aa-forum-topic:hover {
        background-color: rgba(255 220 104 / 25%);
    }

    .aa-forum .panel-aa-forum-personal-messages-item-header {
        border-bottom: 1px solid rgba(200 200 200 / 25%);
    }

    .aa-forum .aa-forum-message-body,
    .aa-forum .aa-forum-message-body-author-signature {
        border-top: 1px solid rgba(200 200 200 / 25%);
    }

    .aa-forum .label-aa-forum-topic-new-message {
        margin-left: 0.5rem;
    }

    .aa-forum .aa-forum-breadcrumb ul {
        margin: 0;
    }

    .aa-forum .btn-aa-forum-topic-moderation {
        border: none;
    }

    /* SumoSelect
    --------------------------------------------------------------------------------- */
    .aa-forum .SumoSelect {
        color: rgb(54 54 54);
    }

    .aa-forum .SumoSelect > .CaptionCont > span.placeholder {
        color: var(--background-color-navigation-default-hover);
    }

    /* END SumoSelect
    --------------------------------------------------------------------------------- */

    .aa-forum .aa-forum-search-results-total-number {
        font-size: 1.25rem;
        font-weight: bolder;
        margin-bottom: 2rem;
    }

    .aa-forum .aa-forum-search-result-counter {
        font-size: 2rem;
        font-weight: bolder;
        margin-right: 1rem;
        min-width: 50px;
        padding: 1rem;
    }

    .aa-forum #aa-forum-form-search-menu {
        padding: 10px 0;
    }

    .aa-forum .aa-forum-breadcrumb {
        padding: 0.2rem;
    }

    .aa-forum .aa-forum-legend > span {
        margin-right: 3rem;
    }

    .aa-forum li.aa-forum-messages-sidebar-menu-item:has(a.active) {
        background-color: var(--background-color-light-transparency) !important;
    }

    .aa-forum li.aa-forum-messages-sidebar-menu-item > a.active {
        color: inherit !important;
    }
}

@media all and (min-width: 768px) {
    .aa-forum #aa-forum-form-search-menu {
        padding: 0;
    }

    .aa-forum .aa-forum-breadcrumb ul li:first-child {
        padding-left: 0;
    }
}

/* END App: AA Forum
------------------------------------------------------------------------------------- */
